@@ -3,8 +3,8 @@ if(class(trees)=="multiPhylo"){
 b<-c()
 u<-c()
 for (i in 1:length(trees)){
-if(is.binary.tree(trees[[i]])!= TRUE) warning(paste("Tree number",i,"is not binary"))
-b[i]<-is.binary.tree(trees[[i]])
+if(is.binary.phylo(trees[[i]])!= TRUE) warning(paste("Tree number",i,"is not binary"))
+b[i]<-is.binary.phylo(trees[[i]])
 if(is.ultrametric(trees[[i]])!= TRUE) warning(paste("Tree number",i,"is not ultrametric"))
 u[i]<-is.ultrametric(trees[[i]])
 }
@@ -13,7 +13,7 @@ if(all(u==TRUE)) print("All trees are ultrametric")
 }
 
 else if(class(trees)=="phylo") {
-if(is.binary.tree(trees)==TRUE) print("Tree is binary") else print("Tree is not binary")
+if(is.binary.phylo(trees)==TRUE) print("Tree is binary") else print("Tree is not binary")
 if(is.ultrametric(trees)==TRUE) print("Tree is ultrametric") else print("Tree is not ultrametric")
 }
 
